﻿# =============================================================================
# >> IMPORTS
# =============================================================================
# EventScripts
import es
import cfglib
import cmdlib
import langlib
import playerlib


# =============================================================================
# >> ADDON INFORMATION
# =============================================================================
info = es.AddonInfo()
info.name        = 'NoZoom'
info.version     = '1.6'
info.author      = 'Ayuto'
info.url         = 'http://addons.eventscripts.com/addons/user/53757'
info.basename    = 'nozoom'
info.description = 'Admins can stop zooming for snipers, sg552, aug'


# =============================================================================
# >> CONFIGURATION
# =============================================================================
config = cfglib.AddonCFG(es.getAddonPath('nozoom') + '/settings.cfg')

config.text('*******************')
config.text('  NoZoom Settings  ')
config.text('*******************')

admins   = config.cvar('nz_admins',   'STEAM_x:x:xxxxxxxx, STEAM_x:x:xxxxxxxx', 'Set the admins, who are allowed to turn NoZoom on/off.')
command  = str(config.cvar('nz_cmd',  '!nz',                                    'Set the command to turn NoZoom on/off.'))
maptypes = config.cvar('nz_maptypes', 'fy, awp, zm, aim, ba, gg, surf',         'Set the maptypes, where players cannot zoom.')
maps     = config.cvar('nz_maps',     'de_dust2, de_dust, cs_office',           'Set the specific maps, where players cannot zoom')
weapons  = config.cvar('nz_weapons',  'awp, scout, sg550, g3sg1, sg552, aug',   'Set the weapons, which cannot zoom.')

config.text(' ')
config.text('Available weapons:')
config.text('awp')
config.text('scout')
config.text('sg550')
config.text('g3sg1')
config.text('sg552')
config.text('aug')

config.write()
config.execute()

es.set('nozoom_version', info.version)
es.makepublic('nozoom_version')


# =============================================================================
# >> GLOBAL VARIABLES
# =============================================================================
prefix  = '#green[#lightgreenNoZoom %s#green]#default '% info.version
Strings = langlib.Strings(es.getAddonPath('nozoom') + '/strings.ini')


# =============================================================================
# >> LOAD & UNLOAD
# =============================================================================
def load():
    cmdlib.registerSayCommand(command, toggleCallback, 'Toggles NoZoom\'s state')
    es.addons.registerTickListener(tick)
    checkMap()

def unload():
    cmdlib.unregisterSayCommand(command)
    es.addons.unregisterTickListener(tick)
    resetNextSecondaryAttack()


# =============================================================================
# >> GAME EVENTS
# =============================================================================
def es_map_start(ev):
    checkMap()

def player_activate(ev):
    player = playerlib.getPlayer(ev['userid'])
    string = ('inactive', 'active')[state]
    msg    = Strings(string, None, player.lang)
    es.tell(player, '#multi', prefix+msg)


# =============================================================================
# >> CALLBACKS
# =============================================================================
def toggleCallback(userid, args):
    if es.getplayersteamid(userid) not in serverVarToList(admins):
        return

    global state
    state = not state
    if not state:
        resetNextSecondaryAttack()

    string = ('disabled', 'enabled')[state]
    for player in playerlib.getPlayerList('#human'):
        es.tell(player, '#multi', prefix + Strings(string, None, player.lang))

def tick():
    if not state:
        return

    prop = 'CBaseCombatWeapon.LocalActiveWeaponData.m_flNextSecondaryAttack'
    for userid in es.getUseridList():
        if es.getplayerprop(userid, 'CBasePlayer.pl.deadflag'):
            continue

        handle = es.getplayerprop(userid, 'CBaseCombatCharacter.m_hActiveWeapon')
        if handle <= 0:
            continue

        index  = es.getindexfromhandle(handle)
        weapon = es.entitygetvalue(index, 'classname')[7:]
        if weapon not in serverVarToList(weapons):
            continue

        es.setindexprop(index, prop, es.getindexprop(index, prop) + 1)


# =============================================================================
# >> FUNCTIONS
# =============================================================================
def serverVarToList(var):
    return str(var).replace(' ', '').split(',')

def checkMap():
    global state
    state  = False
    curmap = es.getString('eventscripts_currentmap')
    if curmap in serverVarToList(maps):
        state = True
        return

    for prefix in serverVarToList(maptypes):
        if curmap.startswith(prefix):
            state = True
            break

def resetNextSecondaryAttack():
    for userid in es.getUseridList():
        if es.getplayerprop(userid, 'CBasePlayer.pl.deadflag'):
            continue

        handle = es.getplayerprop(userid, 'CBaseCombatCharacter.m_hActiveWeapon')
        if handle <= 0:
            continue

        index = es.getindexfromhandle(handle)
        es.setindexprop(index, 'CBaseCombatWeapon.LocalActiveWeaponData.m_flNextSecondaryAttack', 0)